@@ -1,4 +1,4 @@
-{-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE DeriveDataTypeable, OverloadedStrings, ScopedTypeVariables #-}
 {-# OPTIONS_GHC -fno-warn-name-shadowing -fno-warn-orphans #-}
 module Debian.Apt.Index
     ( update
@@ -24,11 +24,14 @@ import qualified Data.Digest.Pure.MD5 as MD5
 import Data.Function
 import Data.List
 import qualified Data.Map as M
+import Data.Monoid ((<>))
+import qualified Data.Text as T (Text, unpack, concat, lines, null, words)
 import Data.Time
 import Debian.Apt.Methods
 import Debian.Control (formatControl)
 import Debian.Control.ByteString
 import Debian.Control.Common
+import Debian.Control.Text (decodeControl)
 --import Debian.Repo.Types
 import Debian.Release
 import Debian.Sources
@@ -166,23 +169,23 @@ calcPath srcType arch baseURI release section =
             maybeOfString s = Just s
 
             wordsBy :: Eq a => (a -> Bool) -> [a] -> [[a]]
-            wordsBy p s = 
+            wordsBy p s =
                 case (break p s) of
                   (s, []) -> [s]
                   (h, t) -> h : wordsBy p (drop 1 t)
 
 -- |Parse a possibly compressed index file.
-controlFromIndex :: Compression -> FilePath -> L.ByteString -> Either ParseError (Control' B.ByteString)
-controlFromIndex GZ path s = parseControl path . B.concat . L.toChunks . GZip.decompress $ s
-controlFromIndex BZ2 path s = parseControl path . B.concat . L.toChunks . BZip.decompress $ s
-controlFromIndex Uncompressed path s = parseControl path . B.concat . L.toChunks $ s
+controlFromIndex :: Compression -> FilePath -> L.ByteString -> Either ParseError (Control' T.Text)
+controlFromIndex GZ path s = either Left (Right . decodeControl) . parseControl path . B.concat . L.toChunks . GZip.decompress $ s
+controlFromIndex BZ2 path s = either Left (Right . decodeControl) . parseControl path . B.concat . L.toChunks . BZip.decompress $ s
+controlFromIndex Uncompressed path s = either Left (Right . decodeControl) . parseControl path . B.concat . L.toChunks $ s
 
--- |parse an index possibly compressed file 
-controlFromIndex' :: Compression -> FilePath -> IO (Either ParseError (Control' B.ByteString))
+-- |parse an index possibly compressed file
+controlFromIndex' :: Compression -> FilePath -> IO (Either ParseError (Control' T.Text))
 controlFromIndex' compression path = L.readFile path >>= return . controlFromIndex compression path
 
 type Size = Integer
-type FileTuple = (CheckSums, Size, FilePath) 
+type FileTuple = (CheckSums, Size, FilePath)
 
 -- |A release file contains a list of indexes (Packages\/Sources). Each
 -- Package or Source index may appear multiple times because it may be
@@ -264,7 +267,7 @@ uncompressedName fp
           | otherwise            = (fp, Uncompressed)
 
 indexesInRelease :: (FilePath -> Bool)
-                 -> Control -- ^ A release file
+                 -> Control' T.Text -- ^ A release file
                  -> [(CheckSums, Integer, FilePath)] -- ^ 
 indexesInRelease filterp (Control [p]) =
     let md5sums =
@@ -272,12 +275,12 @@ indexesInRelease filterp (Control [p]) =
               (Just md5) -> md5
               Nothing -> error $ "Did not find MD5Sum field."
     in
-      filter (\(_,_,fp) -> filterp fp) $ map (makeTuple . B.words) $ filter (not . B.null) (B.lines md5sums)
+      filter (\(_,_,fp) -> filterp fp) $ map (makeTuple . T.words) $ filter (not . T.null) (T.lines md5sums)
     where
-      makeTuple :: [B.ByteString] -> (CheckSums, Integer, FilePath)
-      makeTuple [md5sum, size, fp] = (CheckSums { md5sum = Just (B.unpack md5sum), sha1 = Nothing, sha256 = Nothing }, read (B.unpack size), B.unpack fp)
+      makeTuple :: [T.Text] -> (CheckSums, Integer, FilePath)
+      makeTuple [md5sum, size, fp] = (CheckSums { md5sum = Just (T.unpack md5sum), sha1 = Nothing, sha256 = Nothing }, read (T.unpack size), T.unpack fp)
       makeTuple x = error $ "Invalid line in release file: " ++ show x
-indexesInRelease _ x = error $ "Invalid release file: " ++ B.unpack (B.concat (formatControl x))
+indexesInRelease _ x = error $ "Invalid release file: " <> T.unpack (T.concat (formatControl x))
 
 -- |make a FileTuple for a file found on the local disk
 -- returns 'Nothing' if the file does not exist.
